@@ -8,7 +8,7 @@ require( 'wp-blog-header.php' );
 require_once( ABSPATH . WPINC . '/registration.php' );
 
 if( is_array( get_site_option( 'illegal_names' )) && $_GET[ 'new' ] != '' && in_array( $_GET[ 'new' ], get_site_option( 'illegal_names' ) ) == true ) {
-	header( "Location: http://{$current_site->domain}{$current_site->path}" );
+	wp_redirect( "http://{$current_site->domain}{$current_site->path}" );
 	die();
 }
 
@@ -19,7 +19,7 @@ function signuppageheaders() {
 }
 
 if( $current_blog->domain . $current_blog->path != $current_site->domain . $current_site->path ) {
-	header( "Location: http://" . $current_site->domain . $current_site->path . "wp-signup.php" );
+	wp_redirect( "http://" . $current_site->domain . $current_site->path . "wp-signup.php" );
 	die();
 }
 
@@ -93,7 +93,7 @@ function show_blog_form($blog_id = '', $blog_title = '', $errors = '') {
 <tr>
 <th scope="row"  valign="top"><?php _e('Privacy:') ?></th>
 <td><?php _e('I would like my blog to appear in search engines like Google and Technorati, and in public listings around this site.'); ?> 
-<label><input type="radio" name="blog_public" value="1" <?php if( !isset( $_POST[ 'blog_public' ] ) || $_POST[ 'blog_public' ] == '1' ) { ?>checked="checked"<?php } ?> /> <strong>Yes</strong> </label> <label><input type="radio" name="blog_public" value="0" <?php if( isset( $_POST[ 'blog_public' ] ) && $_POST[ 'blog_public' ] == '0' ) { ?>checked="checked"<?php } ?> /><strong>No</strong> </label> <br />
+<label><input type="radio" name="blog_public" value="1" <?php if( !isset( $_POST[ 'blog_public' ] ) || $_POST[ 'blog_public' ] == '1' ) { ?>checked="checked"<?php } ?> /> <strong><?php _e( 'Yes' ); ?></strong> </label> <label><input type="radio" name="blog_public" value="0" <?php if( isset( $_POST[ 'blog_public' ] ) && $_POST[ 'blog_public' ] == '0' ) { ?>checked="checked"<?php } ?> /><strong><?php _e( 'No' ); ?></strong> </label> <br />
 </tr>
 <?php
 do_action('signup_blogform', $errors);
@@ -308,6 +308,7 @@ function confirm_user_signup($user_name, $user_email) {
 <p><?php printf(__('Check your inbox at <strong>%1$s</strong> and click the link given.  '),  $user_email) ?></p>
 <p><?php _e('If you do not activate your username within two days, you will have to sign up again.'); ?></p>
 <?php
+	do_action('signup_finished');
 }
 
 function signup_blog($user_name = '', $user_email = '', $blog_id = '', $blog_title = '', $errors = '') {
@@ -386,15 +387,19 @@ if( !$active_signup )
 $active_signup = apply_filters( 'wpmu_active_signup', $active_signup ); // return "all", "none", "blog" or "user"
 
 if( is_site_admin() ) {
-	echo "<div style='background: #faf; font-weight: bold; border: 1px solid #333; margin: 2px; padding: 2px'>Greetings Site Administrator! You are currently allowing '$active_signup' registrations. To change or disable registration go to your <a href='wp-admin/wpmu-options.php'>Options page</a>.</div>";
+	echo "<div style='background: #faf; font-weight: bold; border: 1px solid #333; margin: 2px; padding: 2px'>" . sprintf( __( "Greetings Site Administrator! You are currently allowing '%s' registrations. To change or disable registration go to your <a href='wp-admin/wpmu-options.php'>Options page</a>." ), $active_signup ) . "</div>";
 }
 
 $newblogname = isset($_GET['new']) ? strtolower(preg_replace('/^-|-$|[^-a-zA-Z0-9]/', '', $_GET['new'])) : null;
 
+$current_user = wp_get_current_user();
 if( $active_signup == "none" ) {
 	_e( "Registration has been disabled." );
 } else {
-switch ($_POST['stage']) {
+	if( $active_signup == 'blog' && !is_user_logged_in() ) {
+		wp_die( 'You must be logged in to register a blog.' );
+	}
+	switch ($_POST['stage']) {
 	case 'validate-user-signup' :
 		if( $active_signup == 'all' || $_POST[ 'signup_for' ] == 'blog' && $active_signup == 'blog' || $_POST[ 'signup_for' ] == 'user' && $active_signup == 'user' )
 			validate_user_signup();
@@ -431,7 +436,7 @@ switch ($_POST['stage']) {
 			printf(__("<p><em>The blog you were looking for, <strong>%s</strong> doesn't exist but you can create it now!</em></p>"), $newblog );
 		}
 		break;
-}
+	}
 }
 ?>
 </div>
